Draws each sf layer on a single leaflet map, dispatching on geometry type:
polygons are drawn as filled outlines, points as circle markers. A
SpatRaster layer is drawn as a coloured raster image with a legend.
Layers get a toggle in a layers-control.
Examples
map_layers(retrieve_phu_simple(), retrieve_hive()[1:50, ])