Retrieve Ontario Railway Network (ORWN) station points
Source:R/retrieve.R
retrieve_orwn_station.RdRetrieves railway station point locations from the Ontario Railway Network
(ORWN) via the LIO Open Data REST service (LIO_Open04/15).
R/retrieve.R
retrieve_orwn_station.RdRetrieves railway station point locations from the Ontario Railway Network
(ORWN) via the LIO Open Data REST service (LIO_Open04/15).